pub trait PlasticTangentswhere
Self: ElasticPlasticOrViscoplastic,{
// Required methods
fn cauchy_tangent_stiffness_p(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<CauchyTangentStiffnessPlastic, ConstitutiveError>;
fn first_piola_kirchhoff_tangent_stiffness_p(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<FirstPiolaKirchhoffTangentStiffnessPlastic, ConstitutiveError>;
// Provided methods
fn mandel_stress_tangent(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<MandelStressTangentElastic, ConstitutiveError> { ... }
fn mandel_stress_tangent_p(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<MandelStressTangentElasticPlastic, ConstitutiveError> { ... }
}Expand description
Tangents with respect to the plastic deformation gradient, and of the Mandel stress with respect to both deformation gradients — the pieces a coupled (condensed) return map needs beyond the elastic tangents.
Required Methods
Sourcefn cauchy_tangent_stiffness_p(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<CauchyTangentStiffnessPlastic, ConstitutiveError>
fn cauchy_tangent_stiffness_p( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<CauchyTangentStiffnessPlastic, ConstitutiveError>
Calculates and returns the tangent stiffness of the Cauchy stress with respect to the plastic deformation gradient.
\frac{\partial\sigma_{ij}}{\partial F^\mathrm{p}_{NO}} = -\mathcal{T}^\mathrm{e}_{ijmA} F^\mathrm{e}_{mN} F^{\mathrm{p}-1}_{OA}Sourcefn first_piola_kirchhoff_tangent_stiffness_p(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<FirstPiolaKirchhoffTangentStiffnessPlastic, ConstitutiveError>
fn first_piola_kirchhoff_tangent_stiffness_p( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<FirstPiolaKirchhoffTangentStiffnessPlastic, ConstitutiveError>
Calculates and returns the tangent stiffness of the first Piola-Kirchhoff stress with respect to the plastic deformation gradient.
\frac{\partial P_{iJ}}{\partial F^\mathrm{p}_{NO}} = -\mathcal{C}^\mathrm{e}_{iAmB} F^\mathrm{e}_{mN} F^{\mathrm{p}-1}_{OB} F^{\mathrm{p}-1}_{JA} - P_{iO} F^{\mathrm{p}-1}_{JN}Provided Methods
Sourcefn mandel_stress_tangent(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<MandelStressTangentElastic, ConstitutiveError>
fn mandel_stress_tangent( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<MandelStressTangentElastic, ConstitutiveError>
Calculates and returns the tangent stiffness of the Mandel stress with respect to the deformation gradient.
Sourcefn mandel_stress_tangent_p(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<MandelStressTangentElasticPlastic, ConstitutiveError>
fn mandel_stress_tangent_p( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<MandelStressTangentElasticPlastic, ConstitutiveError>
Calculates and returns the tangent stiffness of the Mandel stress with respect to the plastic deformation gradient.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".